* Estimates of Local Ethnic Diversity from the Voter Register  
* for the paper Local Segregation and Violence  
* Kimuli Kasara 
* Replication 
* June 30, 2016

*  ssc install seg 
*SET WORKING DIRECTORY 
  	
** I. Matching register names to areas in which their owners had a majority in 1962 
	    do "EthnicityRegister\namesto1962supermajorityareas.do"

** II. Attaching ethnic group matches to names in the register 
	    do "EthnicityRegister\registernamestoethnicgroups.do" 

** III. Ethnicity Measures 

	*** IIIA. Measures using Location-Level Data 
		 do "EthnicityRegister\ethnicitymeasures_location.do"
		
	*** IIIB. Measures Using Polling Station-Level Data (Segregation Measures and Constituency Measures)
		 do "EthnicityRegister\ethnicitymeasures_pollingstation.do"
		
 
*** IV. Merging and Labeling 
	use   "EthnicityRegister\EthnicGroupsByGroupLoc.dta", clear
			
			sort loc_id_cbm 
			merge 1:1 loc_id_cbm using  "EthnicityRegister\SegIndex.dta"
			table _merge 
			drop _merge 	

		local seg_groups Kikuyu Kalenjin Maasai Luhya Kisii 
		foreach c of local seg_groups {
			sort loc_id_cbm 
			merge 1:1 loc_id_cbm using "EthnicityRegister\Diss_`c'.dta"
			table _merge 
			drop if _merge == 2 
			drop _merge 
			}

			

 
	** Recoding Dissimilarity Index for Small Groups 
		clonevar   diss_2kikuyu  = diss_Kikuyu
		clonevar   diss_2kalenjin  = diss_Kalenjin
		clonevar  diss_2luhya   = diss_Luhya
		clonevar  diss_2maasai  = diss_Maasai
		clonevar  diss_2kisii = diss_Kisii 
		local groups   kalenjin kikuyu kisii  luhya    maasai
		foreach v of local groups {
		replace diss_2`v' = 0 if reg_`v' < .05 & reg_`v' ~=. 
		}
 
		label var HSeg2 "Segregation (Theil's Index)" 
		label var elf_reg "Ethnic Fractionalization" 
			
		label var MSeg2 "Segregation (MI Index)"	
		label var diss_2kikuyu "Kikuyu DI"
		label var diss_2kisii "Kisii DI"
		label var diss_2kalenjin "Kalenjin DI"
		label var diss_2luhya "Luhya DI"
		label var diss_2maasai "Maasai DI"

		keep loc_id_cbm HSeg2 MSeg2 elf_reg  diss_2kalenjin diss_2kikuyu diss_2kisii diss_2luhya diss_2maasai
		
	
	save "EthnicityRegister\EthnicityRegister.dta", replace 		

** V. Erasing Temporary Files 
		local prov_registers prov_nairobi prov_coast prov_northeastern prov_eastern prov_central prov_riftvalley prov_western prov_nyanza
		local part_province  prov_nairobi prov_coast  prov_eastern prov_central prov_riftvalley prov_western prov_nyanza
		local seg_groups Kikuyu Kalenjin Maasai Luhya Kisii 
	 
		erase "EthnicityRegister/name_grpmatches62.dta"
		erase "EthnicityRegister/SegIndex.dta"
		erase "EthnicityRegister/EthnicGroupsByGroupLoc.dta"
		erase "EthnicityRegister/PS_GroupMatches62.dta"
		erase "EthnicityRegister/Registers06_LocData_CollapsedLoc62.dta"
		erase "EthnicityRegister/Registers06_LocData_CollapsedLoc_GroupSumStats62.dta"
		erase "EthnicityRegister/DissimilarityByGroup.dta"
		erase "EthnicityRegister/EthnicConst.dta"
		
		
		foreach c of local seg_groups {
			erase "EthnicityRegister/Diss_`c'.dta"
	 
			}
			
		foreach i of local part_province { 
		erase  "EthnicityRegister/`i'_Base_SegIndex.dta" 
		erase "EthnicityRegister/`i'.dta" 
		}
		 
		 foreach j of local prov_registers {
		 erase "EthnicityRegister/`j'_LocData.dta" 
		 erase "EthnicityRegister/`j'_EIMatches.dta"
		 erase "EthnicityRegister/`j'_cleaned.dta"
	 }
	 



/* 
Original Files and Data Description 	

*1.  C62Locs_ForMatch.dta  
	A dataset of administrative locations in the 1962 census. 
		Variable	Label	Description 
		loc62_id	Location ID (1962) 	ID of 1962 location 
		loc62_name	Location Name (1962)	Name of 1962 location 
		max_grpno	Largest Ethnic Group (1962) 	Largest ethnic group in 1962 location 
		group90	Supermajority Group (1962) 	Ethnic group with over 90% of the population in 1962 location 


* 2 PS_LocMatches62.dta 
	A dataset matching 1962 administrative locations with 2006 polling stations created in ArcGIS. 
		Variable	Label						Description
		constcode	Constituency Code			Constituency Code
		psid		Polling Station ID			Polling station identifer
		psid_rc06	Polling Station ID (2006) 	Polling station identifier (2006) 
		psname_rc06	Polling Station Name (2006)	Polling station name (2006) 
		rc06		= 1 Polling Station in 2006	Indicates whether this was a polling station in 2006
		loc62_id	Location ID (1962) 			ID of location in 1962

*3 Register06_name1_cleaned.dta
	A dataset of all the last names in the voter register cleaned to remove common first names, punctuation, and dipthongs. 
		Variable		Label 								Description 
		name1			Surname	Last name 
		freq			Number of Persons with the Name 	Count of people with that name in the registered 
		name1_id		Name ID and Unique Rank of Name 	Indexes the ranked frequency of that name 
		name1_new		Surname Cleaned						Cleaned version of last name  
		name1_id_new	Name ID and Unique Rank Cleaned 	Indexes the ranked frequency of cleaned  name 
		freq_new		Number of Persons with Cleaned Name Count of people with that cleaned name in the registered 

*4 Register2006/prov_* 
	The original dataset of registered voters in 2006
	The folder â€œRegister2006â€ contains 8 files prefixed prov_ which contain the original registratation data for each province (Central, Coast, Eastern, Nairobi, Northeastern, Nyanza, Rift Valley, Western). 
		Variable 	Label							Description 
		listno		Listed Number of ECK Report		A number indexing the order in which variables appear 
		name1		Surname							Registered voter's surname 
		name2		Other Names 					Registered voter's other names 
		sex			Sex 							Sex 
		id			ID Number						National ID Number 
		elecno		Elector's Number 				Elector's Number
		constcode	Constituency Code 				Constituency Code
		psno		Polling Station Number 			Polling Station Number 
		dob			Date of Birth					Date of Birth 

*5 PS_Loc_Matches_RC06.dta 
	A dataset matching 1999 administrative locations to 2006 polling stations created in ArcGIS. 
		Variable 	Label				Description 
		psid		Polling Station ID	Code identifying polling station (2006) 
		loc_id_cbm	Location Code 		Code identifying administrative location (1999) 
*/ 

 
