* kasara_segregationviolence_qjps_replication.do
* This do-file creates the main tables and appendix tables 
* for the paper Local Segregation and Violence 
* kasara_segregation_qjps_replicationtables.tex creates the tables 
* Kimuli Kasara 
* Replication 
* June 30, 2016


clear
version 10 
set more off 
set linesize 255

** SET WORKING DIRECTORY 
** INSTALL ESTOUT 

 
use  kasara_segregationviolence_qjps.dta, clear

local controls     density62_ln_z area99_ln_z   rain_ln_z eh rgl_pc_z altitude_ln_z ruggedness_ln_z  


** Table 1: Segregation and Violence 

	**save N
	   sum HSeg2_z
	   local n_obs = r(N)
	   display `n_obs'

		
	**************Store Estimates****************
		
		
		**First column, OLS results IDPs
		reg idp_origins_loc_ln_z HSeg2_z `controls'   if   cfdi_block_eh_z~=.
		est store a 	
			
		foreach var of varlist HSeg2_z  density62_ln_z area99_ln_z rain_ln_z eh rgl_pc_z altitude_ln_z ruggedness_ln_z{
		
		local coef1_`var' = _b[`var']
		local se1_`var' = _se[`var']
		   
		}
		
		*check formatting
			
			display `coef1_HSeg2_z'
	 
	   
	   
	   ** Second column RF results IDPs 
	   reg idp_origins_loc_ln_z   `controls'   cfdi_block_eh_z
	   est store b 
			
			
		foreach var of varlist    density62_ln_z area99_ln_z rain_ln_z eh rgl_pc_z altitude_ln_z ruggedness_ln_z cfdi_block_eh_z  {
		
		local coef0_`var' = _b[`var']
		local se0_`var' = _se[`var']
		   
		}
		
	 
	 
	 
	  
	   **Third column, IV results IDPs
	   ivregress 2sls  idp_origins_loc_ln_z  `controls'   (HSeg2_z=cfdi_block_eh_z)   , first  
	  est store c
		**Pull out Fstat and save locally  
		estat firststage 
		mat fstat=r(singleresults)
		estadd scalar fstat1=fstat[1,4], replace   
		local fstat = `:display %12.2f e(fstat1)'
		display `fstat'


	   foreach var of varlist HSeg2_z  density62_ln_z area99_ln_z rain_ln_z eh rgl_pc_z altitude_ln_z ruggedness_ln_z{
		
		local coef2_`var' =_b[`var']
		local se2_`var'= _se[`var']
		   
		}


	*check formatting
			
			display `coef2_HSeg2_z'
	 
		
		**Fourth column, OLS results FIRE BRIGHT
		reg el_bri_ln_z HSeg2_z `controls'  if     cfdi_block_eh_z~=.
		est store d 
		 
	   foreach var of varlist HSeg2_z  density62_ln_z area99_ln_z rain_ln_z eh rgl_pc_z altitude_ln_z ruggedness_ln_z{
		
		local coef3_`var' =_b[`var']
		local se3_`var'= _se[`var']
		   
		}
		
		
		   
	   
	   ** Fifth column RF results IDPs 
	   reg   el_bri_ln_z   `controls'   cfdi_block_eh_z
	   est store e 
			
			
		foreach var of varlist   density62_ln_z area99_ln_z rain_ln_z eh rgl_pc_z altitude_ln_z ruggedness_ln_z cfdi_block_eh_z {
		
		local coef5_`var' = _b[`var']
		local se5_`var' = _se[`var']
		   
		}
		
	 
	 
	 
		
		**Sixth column, IV results FIRE BRIGHT
		ivregress 2sls el_bri_ln_z  `controls'   (HSeg2_z=cfdi_block_eh_z)   , first  
		est store f 
		
		foreach var of varlist HSeg2_z  density62_ln_z area99_ln_z rain_ln_z eh rgl_pc_z altitude_ln_z ruggedness_ln_z{
		
		local coef4_`var' =_b[`var']
		local se4_`var'= _se[`var']
		   
		}
		
 
		
		
		**Table 1.2 Third and Sixth columns, First stage results 
		
		reg  HSeg2_z  density62_ln_z area99_ln_z rain_ln_z eh rgl_pc_z altitude_ln_z ruggedness_ln_z cfdi_block_eh_z 

		foreach var of varlist density62_ln_z area99_ln_z rain_ln_z eh rgl_pc_z altitude_ln_z ruggedness_ln_z cfdi_block_eh_z {
		
		local coef_`var' =_b[`var']
		local se_`var'= _se[`var']
		   
		}
		
		
	**************Make Table 1********************
	 
	

		
		
	  quietly {
	  capture log close
	  log using table1.tex, text replace

	  noisily display "\begin{singlespace}	"
	  noisily display "	\begin{center}	"
	  noisily display "	\begin{threeparttable}[h]\scriptsize	"
	  noisily display "	\caption{Segregation and Violence }\label{table:table1}	"
	  noisily display "	{	"
	  noisily display "	\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}	"
	  noisily display "	\begin{tabular}{l*{6}{c}}	"
	  noisily display "	\toprule	"
	  noisily display "	\emph{Second Stage:} &\multicolumn{3}{c}{\emph{Log. No. of IDPs}}&\multicolumn{3}{c}{\emph{Log. Fire Brightness}}\\	"
	  noisily display "	\cmidrule(lr){2-4}\cmidrule(lr){5-7}	"
	  noisily display "	&\multicolumn{1}{c}{[1]}&\multicolumn{1}{c}{[2]}&\multicolumn{1}{c}{[3]}&\multicolumn{1}{c}{[4]}&\multicolumn{1}{c}{[5]}& \multicolumn{1}{c}{[6]}\\	"
	  
	  noisily display " &\multicolumn{1}{c}{OLS}&\multicolumn{1}{c}{RF}&\multicolumn{1}{c}{IV}&\multicolumn{1}{c}{OLS}&\multicolumn{1}{c}{RF}&\multicolumn{1}{c}{IV}\\	"
	  noisily display "	\midrule	"
	  
	  
	  noisily display "	Segregation (Theil's Index)& " %12.2f `coef1_HSeg2_z' "\sym{***} &     & " %12.2f `coef2_HSeg2_z' " \sym{***}& " %12.2f `coef3_HSeg2_z' "\sym{*} &   & " %12.2f `coef4_HSeg2_z' "\sym{*} \\	"
	  noisily display "	& (" %12.2f `se1_HSeg2_z' ") &   & (" %12.2f `se2_HSeg2_z' ") & (" %12.2f `se3_HSeg2_z' ") &   & (" %12.2f `se4_HSeg2_z' ") \\	"
	  
	  noisily display "	Log. Population Density (1962)& " %12.2f `coef1_density62_ln_z' " &  " %12.2f `coef0_density62_ln_z' " & " %12.2f `coef2_density62_ln_z' " & " %12.2f `coef3_density62_ln_z' "\sym{**}  & " %12.2f `coef5_density62_ln_z'  "\sym{**}  & " %12.2f `coef4_density62_ln_z'  "    \\	"
	  noisily display "	& (" %12.2f `se1_density62_ln_z' ") & (" %12.2f `se0_density62_ln_z' ") & (" %12.2f `se2_density62_ln_z' ") & (" %12.2f `se3_density62_ln_z' ") & (" %12.2f `se5_density62_ln_z' ") & (" %12.2f `se4_density62_ln_z' ") \\	
	  
	  noisily display "	Log. Area & " %12.2f `coef1_area99_ln_z' "\sym{***}& " %12.2f `coef0_area99_ln_z' "\sym{**}&" %12.2f `coef2_area99_ln_z' " & " %12.2f `coef3_area99_ln_z' "\sym{***} & " %12.2f `coef5_area99_ln_z' "\sym{**}& " %12.2f `coef4_area99_ln_z' "\\	"
	  noisily display "	& (" %12.2f `se1_area99_ln_z' ") & (" %12.2f `se0_area99_ln_z' ") & (" %12.2f `se2_area99_ln_z' ") & (" %12.2f `se3_area99_ln_z' ") & (" %12.2f `se5_area99_ln_z' ") & (" %12.2f `se4_area99_ln_z' ") \\	"
	  
	  noisily display "	Log. Rainfall & " %12.2f `coef1_rain_ln_z' "\sym{**} & " %12.2f `coef0_rain_ln_z' " &  " %12.2f `coef2_rain_ln_z' " & " %12.2f `coef3_rain_ln_z' "\sym{***} & " %12.2f `coef5_rain_ln_z' "\sym{***} & " %12.2f `coef4_rain_ln_z' "\\	"
	  noisily display "	& (" %12.2f `se1_rain_ln_z' ") & (" %12.2f `se0_rain_ln_z' ") & (" %12.2f `se2_rain_ln_z' ") & (" %12.2f `se3_rain_ln_z' ")& (" %12.2f `se5_rain_ln_z' ") & (" %12.2f `se4_rain_ln_z' ") \\	"
	  
	  noisily display "	Alienated Area (1934)& " %12.2f `coef1_eh' "\sym{***}& " %12.2f `coef0_eh' "\sym{***}& " %12.2f `coef2_eh' "\sym{**}  & " %12.2f `coef3_eh' " \sym{***} & " %12.2f `coef5_eh' "\sym{**} & " %12.2f `coef4_eh' "\sym{**} \\	"
	  noisily display "	& (" %12.2f `se1_eh' ") & (" %12.2f `se0_eh' ") & (" %12.2f `se2_eh' ") & (" %12.2f `se3_eh' ") & (" %12.2f `se5_eh' ")  & (" %12.2f `se4_eh' ") \\	"
	  
	  noisily display "	Prop. Rangeland & " %12.2f `coef1_rgl_pc_z' " \sym{**} & " %12.2f `coef0_rgl_pc_z' "\sym{***} & " %12.2f `coef2_rgl_pc_z' " & " %12.2f `coef3_rgl_pc_z' " & " %12.2f `coef5_rgl_pc_z' " & " %12.2f `coef4_rgl_pc_z' " \\	"
	  noisily display "	& (" %12.2f `se1_rgl_pc_z' ") 	& (" %12.2f `se0_rgl_pc_z' ") & (" %12.2f `se2_rgl_pc_z' ") & (" %12.2f `se3_rgl_pc_z' ") & (" %12.2f `se5_rgl_pc_z' ") & (" %12.2f `se4_rgl_pc_z' ") \\	"
	  
	  noisily display "	Log. Altitude & " %12.2f `coef1_altitude_ln_z' "\sym{***}&  " %12.2f `coef0_altitude_ln_z' "\sym{***}& " %12.2f `coef2_altitude_ln_z' "\sym{**} & " %12.2f `coef3_altitude_ln_z' " & " %12.2f `coef5_altitude_ln_z' " & " %12.2f `coef4_altitude_ln_z' "\\	"
	  noisily display "	& (" %12.2f `se1_altitude_ln_z' ") &  (" %12.2f `se0_altitude_ln_z' ") & (" %12.2f `se2_altitude_ln_z' ") & (" %12.2f `se3_altitude_ln_z' ") & (" %12.2f `se5_altitude_ln_z' ") & (" %12.2f `se4_altitude_ln_z' ") \\	"
	  
	  noisily display "	Log. Terrain Ruggedness & " %12.2f `coef1_ruggedness_ln_z' "\sym{**} & " %12.2f `coef0_ruggedness_ln_z' "\sym{**} & " %12.2f `coef2_ruggedness_ln_z' " & " %12.2f `coef3_ruggedness_ln_z' " & " %12.2f `coef5_ruggedness_ln_z' " & " %12.2f `coef4_ruggedness_ln_z' "\\	"
	  noisily display "	& (" %12.2f `se1_ruggedness_ln_z' ") & (" %12.2f `se0_ruggedness_ln_z' ") & (" %12.2f `se2_ruggedness_ln_z' ") & (" %12.2f `se3_ruggedness_ln_z' ") & (" %12.2f `se5_ruggedness_ln_z' ") & (" %12.2f `se4_ruggedness_ln_z' ") \\	"
	  
		noisily display "	CFDI &  &" %12.2f `coef0_cfdi_block_eh_z ' "\sym{***} & & & " %12.2f `coef5_cfdi_block_eh_z ' "\sym{**} &   \\	"
	  noisily display "	&   & (" %12.2f `se0_cfdi_block_eh_z ' ") & &   & (" %12.2f `se5_cfdi_block_eh_z ' ")  &   \\	"
	  
	  noisily display "	\midrule	"
	  noisily display "	\textbf{\emph{First-Stage: Segregation }} &\multicolumn{6}{c}{}\\	"
	  noisily display "	\midrule	"
	  
	  noisily display "	CDFI & & & " %12.2f `coef_cfdi_block_eh_z' "\sym{***}&  & & " %12.2f `coef_cfdi_block_eh_z' "\sym{***}\\	"
	  noisily display "	& & & (" %12.2f `se_cfdi_block_eh_z' ") &  & & (" %12.2f `se_cfdi_block_eh_z' ") \\	"
	  
	  noisily display "	Log. Population Density (1962)& & & " %12.2f `coef_density62_ln_z' "  & &  & " %12.2f `coef_density62_ln_z' "\\	"
	  noisily display "	& &  & (" %12.2f `se_density62_ln_z' ") &  & & (" %12.2f `se_density62_ln_z' ") \\	"
	  
	  noisily display "	Log. Area & & &  " %12.2f `coef_area99_ln_z' "\sym{***}&  & & " %12.2f `coef_area99_ln_z' "\sym{***}\\	"
	  noisily display "	& &  & (" %12.2f `se_area99_ln_z' ") & &  & (" %12.2f `se_area99_ln_z' ") \\	"
	  
	  noisily display "	Log. Rainfall & & &  " %12.2f `coef_rain_ln_z' "\sym{***}&  & & " %12.2f `coef_rain_ln_z' "\sym{***}\\	"
	  noisily display "	& & & (" %12.2f `se_rain_ln_z' ") &  & & (" %12.2f `se_rain_ln_z' ") \\	"
	  
	  noisily display "	Alienated Area (1934) & & &  " %12.2f `coef_eh' " &  & & " %12.2f `coef_eh' "\\	"
	  noisily display "	& & &  (" %12.2f `se_eh' ") & &  & (" %12.2f `se_eh' ") \\	"
	  
	  noisily display "	Prop. Rangeland & & & " %12.2f `coef_rgl_pc_z' " &  & & " %12.2f `coef_rgl_pc_z' " \\	"
	  noisily display "	& & & (" %12.2f `se_rgl_pc_z' ") &  & & (" %12.2f `se_rgl_pc_z' ") \\	"
	  
	  noisily display "	Log. Altitude & & & " %12.2f `coef_altitude_ln_z' " & &  & " %12.2f `coef_altitude_ln_z' "\\	"
	  noisily display "	& & & (" %12.2f `se_altitude_ln_z' ") &  & & (" %12.2f `se_altitude_ln_z' ") \\	"
	  
	  noisily display "	Log. Terrain Ruggedness& & &  " %12.2f `coef_ruggedness_ln_z' " & &  & " %12.2f `coef_ruggedness_ln_z' " \\	"
	  noisily display "	& & & (" %12.2f `se_ruggedness_ln_z' ") & &  & (" %12.2f `se_ruggedness_ln_z' ") \\	"
	  
	  noisily display "	\midrule	"
	  noisily display "	N & `n_obs' & `n_obs' & `n_obs'  & `n_obs' & `n_obs' & `n_obs' \\	"
	  noisily display "	F-stat Inst. &  & & `fstat' & & &  `fstat'\\	"
	  noisily display "	\bottomrule	"
	  noisily display "	\end{tabular}	"
	  noisily display "	}	"
	  noisily display "	\begin{tablenotes}[normal,flushleft]	"
	  noisily display "	\item{\emph{Note}: Continuous variables are standardized to have a mean of 0 and a standard deviation of 0.5. Standard errors in parentheses. $^{**}$ \(p<0.05\), $^{***}$ \(p<0.01\).}	"
	  noisily display "	\end{tablenotes}	"
	  noisily display "	\end{threeparttable}	"
	  noisily display "	\end{center}	"
	  noisily display "	\end{singlespace}	"


	  log close

	}

 	
 	
** Table 2: Accounting for Ethnic Diversity   


	**************Store Estimates****************
		
		
		**First column, OLS results IDPs
		reg idp_origins_loc_ln_z MSeg2_z `controls'   if   cfdi_block_eh_z~=.
		est store a 		
			
		foreach var of varlist MSeg2_z  density62_ln_z area99_ln_z rain_ln_z eh rgl_pc_z altitude_ln_z ruggedness_ln_z{
		
		local coef1_`var' = _b[`var']
		local se1_`var' = _se[`var']
		   
		}
		
		*check formatting
			
			display `coef1_MSeg2_z'
		 
	   
	   
		  
	   
	   ** Second column RF results IDPs 
	   reg idp_origins_loc_ln_z   `controls'   cfdi_block_eh_z
	   est store b 
			
			
		foreach var of varlist    density62_ln_z area99_ln_z rain_ln_z eh rgl_pc_z altitude_ln_z ruggedness_ln_z cfdi_block_eh_z  {
		
		local coef0_`var' = _b[`var']
		local se0_`var' = _se[`var']
		   
		}
		
	 
	 
	 
	 
	   **Third column, IV results IDPs
	   ivregress 2sls  idp_origins_loc_ln_z  `controls'   (MSeg2_z=cfdi_block_eh_z)   , first  
		est store c 	
		**Pull out Fstat and save locally  
		estat firststage 
		mat fstat=r(singleresults)
		estadd scalar fstat1=fstat[1,4], replace   
		local fstat = `:display %12.2f e(fstat1)'
		display `fstat'


	   foreach var of varlist MSeg2_z  density62_ln_z area99_ln_z rain_ln_z eh rgl_pc_z altitude_ln_z ruggedness_ln_z{
		
		local coef2_`var' =_b[`var']
		local se2_`var'= _se[`var']
		   
		}


	*check formatting
			
			display `coef2_MSeg2_z'
			*display %12.2f `coef2_MSeg2_z'
		
		**Fourth column, OLS results FIRE BRIGHT
		reg el_bri_ln_z MSeg2_z `controls'  if     cfdi_block_eh_z~=.
		est store d 	
		 
	   foreach var of varlist MSeg2_z  density62_ln_z area99_ln_z rain_ln_z eh rgl_pc_z altitude_ln_z ruggedness_ln_z{
		
		local coef3_`var' =_b[`var']
		local se3_`var'= _se[`var']
		   
		}
		
	** Fifth column RF results IDPs 
	   reg   el_bri_ln_z    `controls'   cfdi_block_eh_z
	   est store e 
			
			
		foreach var of varlist     density62_ln_z area99_ln_z rain_ln_z eh rgl_pc_z altitude_ln_z ruggedness_ln_z cfdi_block_eh_z {
		
		local coef5_`var' = _b[`var']
		local se5_`var' = _se[`var']
		   
		}
		
	 
	 
	 
	 
		**Fourth column, IV results FIRE BRIGHT
		ivregress 2sls el_bri_ln_z  `controls'   (MSeg2_z=cfdi_block_eh_z)   , first  
		est store f 	
		
		foreach var of varlist MSeg2_z  density62_ln_z area99_ln_z rain_ln_z eh rgl_pc_z altitude_ln_z ruggedness_ln_z{
		
		local coef4_`var' =_b[`var']
		local se4_`var'= _se[`var']
		   
		}
		
		*check formatting
			
	 
		
		**Table 2.2 Second and 4th columns, First stage results 
		
		reg  MSeg2_z  density62_ln_z area99_ln_z rain_ln_z eh rgl_pc_z altitude_ln_z ruggedness_ln_z cfdi_block_eh_z 

		foreach var of varlist density62_ln_z area99_ln_z rain_ln_z eh rgl_pc_z altitude_ln_z ruggedness_ln_z cfdi_block_eh_z {
		
		local coef_`var' =_b[`var']
		local se_`var'= _se[`var']
		   
		}
		
	 
		
	**************Make Table 2********************
	 


			
			
		  quietly {
			capture log close
		  log using table2.tex, text replace

		  noisily display "\begin{singlespace}"
		  noisily display "	\begin{center}"
		  noisily display "		\begin{threeparttable}[h]\scriptsize"
		  noisily display "			\caption{Accounting for Ethnic Diversity  }\label{table:table2}"
		  noisily display "			{"
		  noisily display "			\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}"
		  noisily display "			\begin{tabular}{l*{6}{c}}"
		  noisily display "				\toprule"
							
		  noisily display "					&\multicolumn{3}{c}{\emph{Log. No. of IDPs}}&\multicolumn{3}{c}{\emph{Log. Fire Brightness}}\\"
		  noisily display "				\cmidrule(lr){2-4}\cmidrule(lr){5-7}"
		  noisily display "				&\multicolumn{1}{c}{[1]}&\multicolumn{1}{c}{[2]}&\multicolumn{1}{c}{[3]}&\multicolumn{1}{c}{[4]}&\multicolumn{1}{c}{[5]}&\multicolumn{1}{c}{[6]}\\"
		  noisily display "			&\multicolumn{1}{c}{OLS}&\multicolumn{1}{c}{RF}&\multicolumn{1}{c}{IV}&\multicolumn{1}{c}{OLS}&\multicolumn{1}{c}{RF}&\multicolumn{1}{c}{IV}\\"
		  noisily display "				\midrule"
		  
		  noisily display "	Segregation (MI Index)& " %12.2f `coef1_MSeg2_z' "\sym{***} &   &" %12.2f `coef2_MSeg2_z' " \sym{***}& " %12.2f `coef3_MSeg2_z' "\sym{**} &   & " %12.2f `coef4_MSeg2_z' "\sym{**} \\	"
		  noisily display "	& (" %12.2f `se1_MSeg2_z' ") &   & (" %12.2f `se2_MSeg2_z' ") & (" %12.2f `se3_MSeg2_z' ")&   & (" %12.2f `se4_MSeg2_z' ") \\	"
		  
		  noisily display "	Log. Population Density (1962)& " %12.2f `coef1_density62_ln_z' " &  " %12.2f `coef0_density62_ln_z' " & " %12.2f `coef2_density62_ln_z' "\sym{**} & " %12.2f `coef3_density62_ln_z' " & " %12.2f `coef5_density62_ln_z' "   & " %12.2f `coef4_density62_ln_z'  "    \\	"
		  noisily display "	& (" %12.2f `se1_density62_ln_z' ") 	& (" %12.2f `se0_density62_ln_z' ") & (" %12.2f `se2_density62_ln_z' ") & (" %12.2f `se3_density62_ln_z' ") 	& (" %12.2f `se5_density62_ln_z' ") & (" %12.2f `se4_density62_ln_z' ") \\	
		  
		  noisily display "	Log. Area & " %12.2f `coef1_area99_ln_z' "\sym{***} & " %12.2f `coef0_area99_ln_z' "\sym{**} & " %12.2f `coef2_area99_ln_z' " & " %12.2f `coef3_area99_ln_z' "\sym{***}& " %12.2f `coef5_area99_ln_z' "\sym{***} & " %12.2f `coef4_area99_ln_z' "\\	"
		  noisily display "	& (" %12.2f `se1_area99_ln_z' ") & (" %12.2f `se0_area99_ln_z' ")  & (" %12.2f `se2_area99_ln_z' ") & (" %12.2f `se3_area99_ln_z' ") & (" %12.2f `se5_area99_ln_z' ") &  (" %12.2f `se4_area99_ln_z' ") \\	"
		  
		  noisily display "	Log. Rainfall & " %12.2f `coef1_rain_ln_z' " & " %12.2f `coef0_rain_ln_z' " & " %12.2f `coef2_rain_ln_z' " & " %12.2f `coef3_rain_ln_z' "\sym{***}& " %12.2f `coef5_rain_ln_z' "\sym{***}& " %12.2f `coef4_rain_ln_z' "\\	"
		  noisily display "	& (" %12.2f `se1_rain_ln_z' ") & (" %12.2f `se0_rain_ln_z' ") & (" %12.2f `se2_rain_ln_z' ") & (" %12.2f `se3_rain_ln_z' ") &   (" %12.2f `se5_rain_ln_z' ") & (" %12.2f `se4_rain_ln_z' ") \\	"
		  
		  noisily display "	Alienated Area (1934)& " %12.2f `coef1_eh' "\sym{***}& " %12.2f `coef0_eh' "\sym{***}& " %12.2f `coef2_eh' "  & " %12.2f `coef3_eh' " \sym{***}& " %12.2f `coef5_eh' " & " %12.2f `coef4_eh' "\\	"
		  noisily display "	& (" %12.2f `se1_eh' ") & (" %12.2f `se0_eh' ") & (" %12.2f `se2_eh' ") & (" %12.2f `se3_eh' ") & (" %12.2f `se5_eh' ") & (" %12.2f `se4_eh' ") \\	"
		  
		  noisily display "	Prop. Rangeland & " %12.2f `coef1_rgl_pc_z' " \sym{**} & " %12.2f `coef0_rgl_pc_z' " \sym{***} & " %12.2f `coef2_rgl_pc_z' " & " %12.2f `coef3_rgl_pc_z' " & " %12.2f `coef5_rgl_pc_z' " & " %12.2f `coef4_rgl_pc_z' " \\	"
		  noisily display "	& (" %12.2f `se1_rgl_pc_z' ") & (" %12.2f `se0_rgl_pc_z' ") & (" %12.2f `se2_rgl_pc_z' ") & (" %12.2f `se3_rgl_pc_z' ") & (" %12.2f `se5_rgl_pc_z' ") & (" %12.2f `se4_rgl_pc_z' ") \\	"
		  
		  noisily display "	Log. Altitude & " %12.2f `coef1_altitude_ln_z' "\sym{***} &  " %12.2f `coef0_altitude_ln_z' "\sym{***} & " %12.2f `coef2_altitude_ln_z' "\sym{***} & " %12.2f `coef3_altitude_ln_z' " & " %12.2f `coef5_altitude_ln_z' " & " %12.2f `coef4_altitude_ln_z' "\\	"
		  noisily display "	& (" %12.2f `se1_altitude_ln_z' ") & (" %12.2f `se0_altitude_ln_z' ") & (" %12.2f `se2_altitude_ln_z' ") & (" %12.2f `se3_altitude_ln_z' ") & (" %12.2f `se5_altitude_ln_z' ") & (" %12.2f `se4_altitude_ln_z' ") \\	"
		  
		  noisily display "	Log. Terrain Ruggedness & " %12.2f `coef1_ruggedness_ln_z' "\sym{**} & " %12.2f `coef0_ruggedness_ln_z' " & " %12.2f `coef2_ruggedness_ln_z' " & " %12.2f `coef3_ruggedness_ln_z' " & " %12.2f `coef5_ruggedness_ln_z' " & " %12.2f `coef4_ruggedness_ln_z' "\\	"
		  noisily display "	& (" %12.2f `se1_ruggedness_ln_z' ") & (" %12.2f `se0_ruggedness_ln_z' ") & (" %12.2f `se2_ruggedness_ln_z' ") & (" %12.2f `se3_ruggedness_ln_z' ") & (" %12.2f `se5_ruggedness_ln_z' ") & (" %12.2f `se4_ruggedness_ln_z' ") \\	"
		  
			
			noisily display "	CFDI &  &" %12.2f `coef0_cfdi_block_eh_z ' "\sym{***} & & & " %12.2f `coef5_cfdi_block_eh_z ' "\sym{***} &   \\	"
		  noisily display "	&   & (" %12.2f `se0_cfdi_block_eh_z ' ") & &   & (" %12.2f `se5_cfdi_block_eh_z ' ")  &   \\	
		  
		  noisily display "	\midrule	"
		  noisily display "	\textbf{\emph{First-Stage: Segregation }} &\multicolumn{6}{c}{}\\	"
		  noisily display "	\midrule	"
		  
		  noisily display "	CDFI & & & " %12.2f `coef_cfdi_block_eh_z' "\sym{***}& &  & " %12.2f `coef_cfdi_block_eh_z' "\sym{***}\\	"
		  noisily display "	& &  & (" %12.2f `se_cfdi_block_eh_z' ") & &  & (" %12.2f `se_cfdi_block_eh_z' ") \\	"
		  
		  noisily display "	Log. Population Density (1962)& & &  " %12.2f `coef_density62_ln_z' "  & &  & " %12.2f `coef_density62_ln_z' "\\	"
		  noisily display "	& &  & (" %12.2f `se_density62_ln_z' ") & &   &(" %12.2f `se_density62_ln_z' ") \\	"
		  
		  noisily display "	Log. Area & & & " %12.2f `coef_area99_ln_z' "\sym{***}& &  & " %12.2f `coef_area99_ln_z' "\sym{***}\\	"
		  noisily display "	& & & (" %12.2f `se_area99_ln_z' ") & &  & (" %12.2f `se_area99_ln_z' ") \\	"
		  
		  noisily display "	Log. Rainfall & & &  " %12.2f `coef_rain_ln_z' "\sym{***}& &  & " %12.2f `coef_rain_ln_z' "\sym{***}\\	"
		  noisily display "	& & &  (" %12.2f `se_rain_ln_z' ") & &  & (" %12.2f `se_rain_ln_z' ") \\	"
		  
		  noisily display "	Alienated Area (1934) & & &  " %12.2f `coef_eh' " & &  & " %12.2f `coef_eh' "\\	"
		  noisily display "	& & & (" %12.2f `se_eh' ") & &  & (" %12.2f `se_eh' ") \\	"
		  
		  noisily display "	Prop. Rangeland & & &  " %12.2f `coef_rgl_pc_z' " & &  & " %12.2f `coef_rgl_pc_z' " \\	"
		  noisily display "	& & &  (" %12.2f `se_rgl_pc_z' ") & &  & (" %12.2f `se_rgl_pc_z' ") \\	"
		  
		  noisily display "	Log. Altitude & & & " %12.2f `coef_altitude_ln_z' " & &  & " %12.2f `coef_altitude_ln_z' "\\	"
		  noisily display "	& & &  (" %12.2f `se_altitude_ln_z' ") & &  &(" %12.2f `se_altitude_ln_z' ") \\	"
		  
		  noisily display "	Log. Terrain Ruggedness & & & " %12.2f `coef_ruggedness_ln_z' " & & &  " %12.2f `coef_ruggedness_ln_z' " \\	"
		  noisily display "	& & & (" %12.2f `se_ruggedness_ln_z' ") & &  &(" %12.2f `se_ruggedness_ln_z' ") \\	"
		  
		  noisily display "	\midrule	"
		  noisily display "	N & `n_obs' & `n_obs' & `n_obs' & `n_obs'  & `n_obs' & `n_obs'  \\	"
		  noisily display "	F-stat Inst. & & & `fstat' & & & `fstat'\\	"
		  noisily display "	\bottomrule	"
		  noisily display "	\end{tabular}	"
		  noisily display "	}	"
		  noisily display "	\begin{tablenotes}[normal,flushleft]	"
		  noisily display "	\item{\emph{Note}: Continuous variables are standardized to have a mean of 0 and a standard deviation of 0.5. Standard errors in parentheses. $^{**}$ \(p<0.05\), $^{***}$ \(p<0.01\).}	"
		  noisily display "	\end{tablenotes}	"
		  noisily display "	\end{threeparttable}	"
		  noisily display "	\end{center}	"
		  noisily display "	\end{singlespace}	"


		  log close

		}



	** Table 3: Exploring Mechanisms


	**************Store Estimates****************
		

		
		** First column, IV IDP Below Median - Ruggedness 
		
		
		ivregress 2sls  idp_origins_loc_ln_z  `controls'   (HSeg2_z=cfdi_block_eh_z)  if  ruggedness_above_med == 0 , first
		est store a 
		
			
		foreach var of varlist HSeg2_z  density62_ln_z area99_ln_z rain_ln_z eh rgl_pc_z altitude_ln_z ruggedness_ln_z{
			
		local coef1_`var' = _b[`var']
		local se1_`var' = _se[`var']
		   
		}
		
		** Second column, IV IDP Above Median - Ruggedness
		
		
		ivregress 2sls  idp_origins_loc_ln_z  `controls'   (HSeg2_z=cfdi_block_eh_z) if   ruggedness_above_med == 1 , first
		est store b 
		
			
		foreach var of varlist HSeg2_z  density62_ln_z area99_ln_z rain_ln_z eh rgl_pc_z altitude_ln_z ruggedness_ln_z{
		
		local coef2_`var' = _b[`var']
		local se2_`var' = _se[`var']
		   
		}
		
		** Third column, IV IDP Below Median - Road  
		
		ivregress 2sls  idp_origins_loc_ln_z  `controls'   (HSeg2_z=cfdi_block_eh_z)  if  road_above_med == 0 , first
		est store c 
		
		
			
		foreach var of varlist HSeg2_z  density62_ln_z area99_ln_z rain_ln_z eh rgl_pc_z altitude_ln_z ruggedness_ln_z{
		
		local coef3_`var' = _b[`var']
		local se3_`var' = _se[`var']
		   
		}
		
		
		** Fourth column, IV IDP Above Median - Road   
		
		
		ivregress 2sls  idp_origins_loc_ln_z  `controls'   (HSeg2_z=cfdi_block_eh_z) if   road_above_med == 1 , first
		est store d 
	 
		
		foreach var of varlist HSeg2_z  density62_ln_z area99_ln_z rain_ln_z eh rgl_pc_z altitude_ln_z ruggedness_ln_z{
		
		local coef4_`var' = _b[`var']
		local se4_`var' = _se[`var']
		   
		}
		
		** Fifth column, IV FIRE  Below Median - Ruggedness 
		
		
		ivregress 2sls  el_bri_ln_z  `controls'   (HSeg2_z=cfdi_block_eh_z)  if  ruggedness_above_med == 0 , first
		est store e 
		
			
		foreach var of varlist HSeg2_z  density62_ln_z area99_ln_z rain_ln_z eh rgl_pc_z altitude_ln_z ruggedness_ln_z{
		
		local coef5_`var' = _b[`var']
		local se5_`var' = _se[`var']
		   
		}
		
		
		** Sixth column, IV FIRE Above Median - Ruggedness
		
		
		ivregress 2sls  el_bri_ln_z  `controls'   (HSeg2_z=cfdi_block_eh_z) if   ruggedness_above_med == 1 , first
		est store f 
		
			
		foreach var of varlist HSeg2_z  density62_ln_z area99_ln_z rain_ln_z eh rgl_pc_z altitude_ln_z ruggedness_ln_z{
		
		local coef6_`var' = _b[`var']
		local se6_`var' = _se[`var']
		   
		}
		
		** Seventh column, IV FIRE Below Median - Road  
		
		ivregress 2sls  el_bri_ln_z  `controls'   (HSeg2_z=cfdi_block_eh_z)  if  road_above_med == 0 , first
		est store g 
		
			
		foreach var of varlist HSeg2_z  density62_ln_z area99_ln_z rain_ln_z eh rgl_pc_z altitude_ln_z ruggedness_ln_z{
		
		local coef7_`var' = _b[`var']
		local se7_`var' = _se[`var']
		   
		}
		
		** Eight  column, IV FIRE Above Median - Road   
		
		
		ivregress 2sls  el_bri_ln_z  `controls'   (HSeg2_z=cfdi_block_eh_z) if   road_above_med == 1 , first
		est store h 
	 
		
		foreach var of varlist HSeg2_z  density62_ln_z area99_ln_z rain_ln_z eh rgl_pc_z altitude_ln_z ruggedness_ln_z{
		
		local coef8_`var' = _b[`var']
		local se8_`var' = _se[`var']
		   
		}
  
		

		
	  quietly {
		capture log close
	  log using table3.tex, text replace
	noisily display "\begin{singlespace} "
	noisily display "\begin{landscape} "
	noisily display "\begin{center} "
	noisily display "\begin{threeparttable}\scriptsize "
	noisily display "\caption{Exploring Mechanisms  }\label{table:table3} "
	noisily display "{ "
	noisily display "\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi} "
	noisily display "\begin{tabular}{l*{8}{c}} "
	noisily display "\toprule "
	noisily display "   \emph{Second Stage:}              &\multicolumn{4}{c}{\emph{Log. No. of IDPs}}&\multicolumn{4}{c}{\emph{Log. Fire Brightness}}\\  "
	noisily display "    \cmidrule(lr){2-5}\cmidrule(lr){6-9} "
	noisily display "              &\multicolumn{2}{c}{Terrain Ruggedness}&\multicolumn{2}{c}{Distance to Road}  &\multicolumn{2}{c}{Terrain Ruggedness}&\multicolumn{2}{c}{Distance to Road}  \\  "
	noisily display "                &\multicolumn{1}{c}{$<$ Median}&\multicolumn{1}{c}{$>$ Median}&\multicolumn{1}{c}{$<$ Median}&\multicolumn{1}{c}{$>$ Median}&\multicolumn{1}{c}{$<$ Median}&\multicolumn{1}{c}{$>$ Median}&\multicolumn{1}{c}{$<$ Median}&\multicolumn{1}{c}{$>$ Median}\\  "
	noisily display "                &\multicolumn{1}{c}{[1]}&\multicolumn{1}{c}{[2]}&\multicolumn{1}{c}{[3]}&\multicolumn{1}{c}{[4]}&\multicolumn{1}{c}{[5]}&\multicolumn{1}{c}{[6]}&\multicolumn{1}{c}{[7]}&\multicolumn{1}{c}{[8]}\\ "

	noisily display " \midrule "
	noisily display " Segregation (Theil's Index)&    " %12.2f `coef1_HSeg2_z' "\sym{**} &    " %12.2f `coef2_HSeg2_z' "        &     " %12.2f `coef3_HSeg2_z' "   &     " %12.2f `coef4_HSeg2_z' "        &     " %12.2f `coef5_HSeg2_z' "\sym{*} &   " %12.2f `coef6_HSeg2_z' "       &   " %12.2f `coef7_HSeg2_z' "        &    " %12.2f `coef8_HSeg2_z' "\\ "
	 noisily display "                &   (" %12.2f `se1_HSeg2_z' ")      &   (" %12.2f `se2_HSeg2_z' ")        &   (" %12.2f `se3_HSeg2_z' ")         &   (" %12.2f `se4_HSeg2_z' ")        &   (" %12.2f `se5_HSeg2_z' ")         &   (" %12.2f `se6_HSeg2_z' ")        &   (" %12.2f `se7_HSeg2_z' ")        &   (" %12.2f `se8_HSeg2_z' ")       \\ "
	noisily display " Log. Population Density (1962)&   " %12.2f `coef1_density62_ln_z' "         &     " %12.2f `coef2_density62_ln_z' " \sym{**} &    " %12.2f `coef3_density62_ln_z' "         &     " %12.2f `coef4_density62_ln_z' "  &    " %12.2f `coef5_density62_ln_z' "          &   " %12.2f `coef6_density62_ln_z' "        &    " %12.2f `coef7_density62_ln_z' "        &    " %12.2f `coef8_density62_ln_z' "      \\  "
	 noisily display "                &   (" %12.2f `se1_density62_ln_z' ") &   (" %12.2f `se2_density62_ln_z' ")        &   (" %12.2f `se3_density62_ln_z' ")          &    (" %12.2f `se4_density62_ln_z' ")         &   (" %12.2f `se5_density62_ln_z' ")         &    (" %12.2f `se63_density62_ln_z' ")          &    (" %12.2f `se7_density62_ln_z' ")        &    (" %12.2f `se8_density62_ln_z' ")          \\ "
	noisily display " Log. Area       &    " %12.2f `coef1_area99_ln_z' "        &      " %12.2f `coef2_area99_ln_z' "       &    " %12.2f `coef3_area99_ln_z' "        &      " %12.2f `coef4_area99_ln_z' "        &     " %12.2f `coef5_area99_ln_z' "       &      " %12.2f `coef6_area99_ln_z' "\sym{***}&     " %12.2f `coef7_area99_ln_z' "         &     " %12.2f `coef8_area99_ln_z' "\sym{***}\\ "
	noisily display "                 &   (" %12.2f `se1_area99_ln_z' ")         &  (" %12.2f `se2_area99_ln_z' ")       &   (" %12.2f `se3_area99_ln_z' ")        &  (" %12.2f `se4_area99_ln_z' ")        &  (" %12.2f `se5_area99_ln_z' ")        &  (" %12.2f `se6_area99_ln_z' ")        &   (" %12.2f `se7_area99_ln_z' ")       &   (" %12.2f `se8_area99_ln_z' ")       \\ "
	noisily display " Log. Rainfall   &   " %12.2f `coef1_rain_ln_z' "        &     " %12.2f `coef2_rain_ln_z' "        &   " %12.2f `coef3_rain_ln_z' "       &     " %12.2f `coef4_rain_ln_z' "         &  " %12.2f `coef5_rain_ln_z' "         &    " %12.2f `coef6_rain_ln_z' " \sym{***}&   " %12.2f `coef7_rain_ln_z' "         &     " %12.2f `coef8_rain_ln_z' " \sym{**} \\ "
	 noisily display "                &  (" %12.2f `se1_rain_ln_z' ")         &   (" %12.2f `se2_rain_ln_z' ")        &  (" %12.2f `se3_rain_ln_z' ")        &   (" %12.2f `se4_rain_ln_z' ")         &   (" %12.2f `se5_rain_ln_z' ")        &   (" %12.2f `se6_rain_ln_z' ")         &   (" %12.2f `se7_rain_ln_z' ")        &   (" %12.2f `se8_rain_ln_z' ")      \\ "
	noisily display " Alienated Area (1934)&    " %12.2f `coef1_eh' "      &   " %12.2f `coef2_eh' "\sym{***}&     " %12.2f `coef3_eh' "         &     " %12.2f `coef4_eh' "\sym{***}&    " %12.2f `coef5_eh' "       &     " %12.2f `coef6_eh' "\sym{***}&     " %12.2f `coef7_eh' "      &     " %12.2f `coef8_eh' "\sym{**} \\ "
	noisily display "                 &   (" %12.2f `se1_eh' ")        &   (" %12.2f `se2_eh' ")       &  (" %12.2f `se3_eh' ")        &   (" %12.2f `se4_eh' ")      &   (" %12.2f `se5_eh' ")         &  (" %12.2f `se6_eh' ")        &   (" %12.2f `se7_eh' ")       &   (" %12.2f `se8_eh' ")       \\ "
	noisily display " Prop. Rangeland &     " %12.2f `coef1_rgl_pc_z' "          &   " %12.2f `coef2_rgl_pc_z' "         &   " %12.2f `coef3_rgl_pc_z' "        &    " %12.2f `coef4_rgl_pc_z' "         &     " %12.2f `coef5_rgl_pc_z' "         &    " %12.2f `coef6_rgl_pc_z' "         &    " %12.2f `coef7_rgl_pc_z' "         &     " %12.2f `coef8_rgl_pc_z' "         \\ "
	 noisily display "                &   (" %12.2f `se1_rgl_pc_z' ")         &  (" %12.2f `se2_rgl_pc_z' ")       &   (" %12.2f `se3_rgl_pc_z' ")        &   (" %12.2f `se4_rgl_pc_z' ")         &   (" %12.2f `se5_rgl_pc_z' ")        &   (" %12.2f `se6_rgl_pc_z' ")        &   (" %12.2f `se7_rgl_pc_z' ")       &   (" %12.2f `se8_rgl_pc_z' ")         \\ "
	noisily display " Log. Altitude   &     " %12.2f `coef1_altitude_ln_z' "       &      " %12.2f `coef2_altitude_ln_z' "\sym{**} &      " %12.2f `coef3_altitude_ln_z' "   &      " %12.2f `coef4_altitude_ln_z' "\sym{**} &     " %12.2f `coef5_altitude_ln_z' "        &    " %12.2f `coef6_altitude_ln_z' "        &     " %12.2f `coef7_altitude_ln_z' "         &     " %12.2f `coef8_altitude_ln_z' "       \\ "
	 noisily display "                &   (" %12.2f `se1_altitude_ln_z' ")        &  (" %12.2f `se2_altitude_ln_z' ")         &  (" %12.2f `se3_altitude_ln_z' ")        &   (" %12.2f `se4_altitude_ln_z' ")         &   (" %12.2f `se5_altitude_ln_z' ")   &  (" %12.2f `se6_altitude_ln_z' ")       &   (" %12.2f `se7_altitude_ln_z' ")        &   (" %12.2f `se8_altitude_ln_z' ")       \\ "
	noisily display " Log. Terrain Ruggedness&     " %12.2f `coef1_ruggedness_ln_z' " &    " %12.2f `coef2_ruggedness_ln_z' "          &   " %12.2f `coef3_ruggedness_ln_z' "         &    " %12.2f `coef4_ruggedness_ln_z' "          &   " %12.2f `coef5_ruggedness_ln_z' "         &   " %12.2f `coef6_ruggedness_ln_z' "         &   " %12.2f `coef7_ruggedness_ln_z' "         &     " %12.2f `coef8_ruggedness_ln_z' "          \\ "
	noisily display "               &   (" %12.2f `se1_ruggedness_ln_z' ")         &   (" %12.2f `se2_ruggedness_ln_z' ")        &  (" %12.2f `se3_ruggedness_ln_z' ")      &  (" %12.2f `se4_ruggedness_ln_z' ")         &   (" %12.2f `se5_ruggedness_ln_z' ")         &  (" %12.2f `se6_ruggedness_ln_z' ")       &   (" %12.2f `se7_ruggedness_ln_z' ")         &   (" %12.2f `se8_ruggedness_ln_z' ")        \\ "

	noisily display " \midrule "
	noisily display " N    &      358         &      359         &      357         &      360         &      358         &      359         &      357         &      360         \\ " 
	noisily display " \bottomrule "
	noisily display " \end{tabular} "
	noisily display " } "
	noisily display " \begin{tablenotes}[normal,flushleft] "
	noisily display "  \item{\emph{Note}: Continuous variables are standardized to have a mean of 0 and a standard deviation of 0.5. Standard errors in parentheses. $^{**}$ \(p<0.05\), $^{***}$ \(p<0.01\).} "
	noisily display " \end{tablenotes} "
	noisily display " \end{threeparttable} "
	noisily display " \end{center} "
	noisily display " \end{landscape} "
	noisily display " \end{singlespace} "
	  
	  log close

	}
	


** Table 3: Exploring Mechanisms


	**************Store Estimates****************
		

		
		** First column, IV IDP Below Median - Ruggedness 
		
		
		ivregress 2sls  idp_origins_loc_ln_z  `controls'   (HSeg2_z=cfdi_block_eh_z)  if  ruggedness_above_med == 0 , first
		est store a 
		
			
		foreach var of varlist HSeg2_z  density62_ln_z area99_ln_z rain_ln_z eh rgl_pc_z altitude_ln_z ruggedness_ln_z{
			
		local coef1_`var' = _b[`var']
		local se1_`var' = _se[`var']
		   
		}
		
		** Second column, IV IDP Above Median - Ruggedness
		
		
		ivregress 2sls  idp_origins_loc_ln_z  `controls'   (HSeg2_z=cfdi_block_eh_z) if   ruggedness_above_med == 1 , first
		est store b 
		
			
		foreach var of varlist HSeg2_z  density62_ln_z area99_ln_z rain_ln_z eh rgl_pc_z altitude_ln_z ruggedness_ln_z{
		
		local coef2_`var' = _b[`var']
		local se2_`var' = _se[`var']
		   
		}
		
		** Third column, IV IDP Below Median - Road  
		
		ivregress 2sls  idp_origins_loc_ln_z  `controls'   (HSeg2_z=cfdi_block_eh_z)  if  road_above_med == 0 , first
		est store c 
		
		
			
		foreach var of varlist HSeg2_z  density62_ln_z area99_ln_z rain_ln_z eh rgl_pc_z altitude_ln_z ruggedness_ln_z{
		
		local coef3_`var' = _b[`var']
		local se3_`var' = _se[`var']
		   
		}
		
		
		** Fourth column, IV IDP Above Median - Road   
		
		
		ivregress 2sls  idp_origins_loc_ln_z  `controls'   (HSeg2_z=cfdi_block_eh_z) if   road_above_med == 1 , first
		est store d 
	 
		
		foreach var of varlist HSeg2_z  density62_ln_z area99_ln_z rain_ln_z eh rgl_pc_z altitude_ln_z ruggedness_ln_z{
		
		local coef4_`var' = _b[`var']
		local se4_`var' = _se[`var']
		   
		}
		
		** Fifth column, IV FIRE  Below Median - Ruggedness 
		
		
		ivregress 2sls  el_bri_ln_z  `controls'   (HSeg2_z=cfdi_block_eh_z)  if  ruggedness_above_med == 0 , first
		est store e 
		
			
		foreach var of varlist HSeg2_z  density62_ln_z area99_ln_z rain_ln_z eh rgl_pc_z altitude_ln_z ruggedness_ln_z{
		
		local coef5_`var' = _b[`var']
		local se5_`var' = _se[`var']
		   
		}
		
		
		** Sixth column, IV FIRE Above Median - Ruggedness
		
		
		ivregress 2sls  el_bri_ln_z  `controls'   (HSeg2_z=cfdi_block_eh_z) if   ruggedness_above_med == 1 , first
		est store f 
		
			
		foreach var of varlist HSeg2_z  density62_ln_z area99_ln_z rain_ln_z eh rgl_pc_z altitude_ln_z ruggedness_ln_z{
		
		local coef6_`var' = _b[`var']
		local se6_`var' = _se[`var']
		   
		}
		
		** Seventh column, IV FIRE Below Median - Road  
		
		ivregress 2sls  el_bri_ln_z  `controls'   (HSeg2_z=cfdi_block_eh_z)  if  road_above_med == 0 , first
		est store g 
		
			
		foreach var of varlist HSeg2_z  density62_ln_z area99_ln_z rain_ln_z eh rgl_pc_z altitude_ln_z ruggedness_ln_z{
		
		local coef7_`var' = _b[`var']
		local se7_`var' = _se[`var']
		   
		}
		
		** Eight  column, IV FIRE Above Median - Road   
		
		
		ivregress 2sls  el_bri_ln_z  `controls'   (HSeg2_z=cfdi_block_eh_z) if   road_above_med == 1 , first
		est store h 
	 
		
		foreach var of varlist HSeg2_z  density62_ln_z area99_ln_z rain_ln_z eh rgl_pc_z altitude_ln_z ruggedness_ln_z{
		
		local coef8_`var' = _b[`var']
		local se8_`var' = _se[`var']
		   
		}

	 


		
	  quietly {
		capture log close
	  log using table3.tex, text replace
	noisily display "\begin{singlespace} "
	noisily display "\begin{landscape} "
	noisily display "\begin{center} "
	noisily display "\begin{threeparttable}\scriptsize "
	noisily display "\caption{Exploring Mechanisms  }\label{table:table3} "
	noisily display "{ "
	noisily display "\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi} "
	noisily display "\begin{tabular}{l*{8}{c}} "
	noisily display "\toprule "
	noisily display "   \emph{Second Stage:}              &\multicolumn{4}{c}{\emph{Log. No. of IDPs}}&\multicolumn{4}{c}{\emph{Log. Fire Brightness}}\\  "
	noisily display "    \cmidrule(lr){2-5}\cmidrule(lr){6-9} "
	noisily display "              &\multicolumn{2}{c}{Terrain Ruggedness}&\multicolumn{2}{c}{Distance to Road}  &\multicolumn{2}{c}{Terrain Ruggedness}&\multicolumn{2}{c}{Distance to Road}  \\  "
	noisily display "                &\multicolumn{1}{c}{$<$ Median}&\multicolumn{1}{c}{$>$ Median}&\multicolumn{1}{c}{$<$ Median}&\multicolumn{1}{c}{$>$ Median}&\multicolumn{1}{c}{$<$ Median}&\multicolumn{1}{c}{$>$ Median}&\multicolumn{1}{c}{$<$ Median}&\multicolumn{1}{c}{$>$ Median}\\  "
	noisily display "                &\multicolumn{1}{c}{[1]}&\multicolumn{1}{c}{[2]}&\multicolumn{1}{c}{[3]}&\multicolumn{1}{c}{[4]}&\multicolumn{1}{c}{[5]}&\multicolumn{1}{c}{[6]}&\multicolumn{1}{c}{[7]}&\multicolumn{1}{c}{[8]}\\ "

	noisily display " \midrule "
	noisily display " Segregation (Theil's Index)&    " %12.2f `coef1_HSeg2_z' "\sym{**} &    " %12.2f `coef2_HSeg2_z' "        &     " %12.2f `coef3_HSeg2_z' "   &     " %12.2f `coef4_HSeg2_z' "        &     " %12.2f `coef5_HSeg2_z' " &   " %12.2f `coef6_HSeg2_z' "       &   " %12.2f `coef7_HSeg2_z' "        &    " %12.2f `coef8_HSeg2_z' "\\ "
	 noisily display "                &   (" %12.2f `se1_HSeg2_z' ")      &   (" %12.2f `se2_HSeg2_z' ")        &   (" %12.2f `se3_HSeg2_z' ")         &   (" %12.2f `se4_HSeg2_z' ")        &   (" %12.2f `se5_HSeg2_z' ")         &   (" %12.2f `se6_HSeg2_z' ")        &   (" %12.2f `se7_HSeg2_z' ")        &   (" %12.2f `se8_HSeg2_z' ")       \\ "
	noisily display " Log. Population Density (1962)&   " %12.2f `coef1_density62_ln_z' "         &     " %12.2f `coef2_density62_ln_z' " \sym{**} &    " %12.2f `coef3_density62_ln_z' "         &     " %12.2f `coef4_density62_ln_z' "  &    " %12.2f `coef5_density62_ln_z' "          &   " %12.2f `coef6_density62_ln_z' "        &    " %12.2f `coef7_density62_ln_z' "        &    " %12.2f `coef8_density62_ln_z' "      \\  "
	 noisily display "                &   (" %12.2f `se1_density62_ln_z' ") &   (" %12.2f `se2_density62_ln_z' ")        &   (" %12.2f `se3_density62_ln_z' ")          &    (" %12.2f `se4_density62_ln_z' ")         &   (" %12.2f `se5_density62_ln_z' ")         &    (" %12.2f `se63_density62_ln_z' ")          &    (" %12.2f `se7_density62_ln_z' ")        &    (" %12.2f `se8_density62_ln_z' ")          \\ "
	noisily display " Log. Area       &    " %12.2f `coef1_area99_ln_z' "        &      " %12.2f `coef2_area99_ln_z' "       &    " %12.2f `coef3_area99_ln_z' "        &      " %12.2f `coef4_area99_ln_z' "        &     " %12.2f `coef5_area99_ln_z' "       &      " %12.2f `coef6_area99_ln_z' "\sym{***}&     " %12.2f `coef7_area99_ln_z' "         &     " %12.2f `coef8_area99_ln_z' "\sym{***}\\ "
	noisily display "                 &   (" %12.2f `se1_area99_ln_z' ")         &  (" %12.2f `se2_area99_ln_z' ")       &   (" %12.2f `se3_area99_ln_z' ")        &  (" %12.2f `se4_area99_ln_z' ")        &  (" %12.2f `se5_area99_ln_z' ")        &  (" %12.2f `se6_area99_ln_z' ")        &   (" %12.2f `se7_area99_ln_z' ")       &   (" %12.2f `se8_area99_ln_z' ")       \\ "
	noisily display " Log. Rainfall   &   " %12.2f `coef1_rain_ln_z' "        &     " %12.2f `coef2_rain_ln_z' "        &   " %12.2f `coef3_rain_ln_z' "       &     " %12.2f `coef4_rain_ln_z' "         &  " %12.2f `coef5_rain_ln_z' "         &    " %12.2f `coef6_rain_ln_z' " \sym{***}&   " %12.2f `coef7_rain_ln_z' "         &     " %12.2f `coef8_rain_ln_z' " \sym{**} \\ "
	 noisily display "                &  (" %12.2f `se1_rain_ln_z' ")         &   (" %12.2f `se2_rain_ln_z' ")        &  (" %12.2f `se3_rain_ln_z' ")        &   (" %12.2f `se4_rain_ln_z' ")         &   (" %12.2f `se5_rain_ln_z' ")        &   (" %12.2f `se6_rain_ln_z' ")         &   (" %12.2f `se7_rain_ln_z' ")        &   (" %12.2f `se8_rain_ln_z' ")      \\ "
	noisily display " Alienated Area (1934)&    " %12.2f `coef1_eh' "      &   " %12.2f `coef2_eh' "\sym{***}&     " %12.2f `coef3_eh' "         &     " %12.2f `coef4_eh' "\sym{***}&    " %12.2f `coef5_eh' "       &     " %12.2f `coef6_eh' "\sym{***}&     " %12.2f `coef7_eh' "      &     " %12.2f `coef8_eh' "\sym{**} \\ "
	noisily display "                 &   (" %12.2f `se1_eh' ")        &   (" %12.2f `se2_eh' ")       &  (" %12.2f `se3_eh' ")        &   (" %12.2f `se4_eh' ")      &   (" %12.2f `se5_eh' ")         &  (" %12.2f `se6_eh' ")        &   (" %12.2f `se7_eh' ")       &   (" %12.2f `se8_eh' ")       \\ "
	noisily display " Prop. Rangeland &     " %12.2f `coef1_rgl_pc_z' "          &   " %12.2f `coef2_rgl_pc_z' "         &   " %12.2f `coef3_rgl_pc_z' "        &    " %12.2f `coef4_rgl_pc_z' "         &     " %12.2f `coef5_rgl_pc_z' "         &    " %12.2f `coef6_rgl_pc_z' "         &    " %12.2f `coef7_rgl_pc_z' "         &     " %12.2f `coef8_rgl_pc_z' "         \\ "
	 noisily display "                &   (" %12.2f `se1_rgl_pc_z' ")         &  (" %12.2f `se2_rgl_pc_z' ")       &   (" %12.2f `se3_rgl_pc_z' ")        &   (" %12.2f `se4_rgl_pc_z' ")         &   (" %12.2f `se5_rgl_pc_z' ")        &   (" %12.2f `se6_rgl_pc_z' ")        &   (" %12.2f `se7_rgl_pc_z' ")       &   (" %12.2f `se8_rgl_pc_z' ")         \\ "
	noisily display " Log. Altitude   &     " %12.2f `coef1_altitude_ln_z' "       &      " %12.2f `coef2_altitude_ln_z' "\sym{**} &      " %12.2f `coef3_altitude_ln_z' "   &      " %12.2f `coef4_altitude_ln_z' "\sym{**} &     " %12.2f `coef5_altitude_ln_z' "        &    " %12.2f `coef6_altitude_ln_z' "        &     " %12.2f `coef7_altitude_ln_z' "         &     " %12.2f `coef8_altitude_ln_z' "       \\ "
	 noisily display "                &   (" %12.2f `se1_altitude_ln_z' ")        &  (" %12.2f `se2_altitude_ln_z' ")         &  (" %12.2f `se3_altitude_ln_z' ")        &   (" %12.2f `se4_altitude_ln_z' ")         &   (" %12.2f `se5_altitude_ln_z' ")   &  (" %12.2f `se6_altitude_ln_z' ")       &   (" %12.2f `se7_altitude_ln_z' ")        &   (" %12.2f `se8_altitude_ln_z' ")       \\ "
	noisily display " Log. Terrain Ruggedness&     " %12.2f `coef1_ruggedness_ln_z' " &    " %12.2f `coef2_ruggedness_ln_z' "          &   " %12.2f `coef3_ruggedness_ln_z' "         &    " %12.2f `coef4_ruggedness_ln_z' "          &   " %12.2f `coef5_ruggedness_ln_z' "         &   " %12.2f `coef6_ruggedness_ln_z' "         &   " %12.2f `coef7_ruggedness_ln_z' "         &     " %12.2f `coef8_ruggedness_ln_z' "          \\ "
	noisily display "               &   (" %12.2f `se1_ruggedness_ln_z' ")         &   (" %12.2f `se2_ruggedness_ln_z' ")        &  (" %12.2f `se3_ruggedness_ln_z' ")      &  (" %12.2f `se4_ruggedness_ln_z' ")         &   (" %12.2f `se5_ruggedness_ln_z' ")         &  (" %12.2f `se6_ruggedness_ln_z' ")       &   (" %12.2f `se7_ruggedness_ln_z' ")         &   (" %12.2f `se8_ruggedness_ln_z' ")        \\ "

	noisily display " \midrule "
	noisily display " N    &      358         &      359         &      357         &      360         &      358         &      359         &      357         &      360         \\ " 
	noisily display " \bottomrule "
	noisily display " \end{tabular} "
	noisily display " } "
	noisily display " \begin{tablenotes}[normal,flushleft] "
	noisily display "  \item{\emph{Note}: Continuous variables are standardized to have a mean of 0 and a standard deviation of 0.5. Standard errors in parentheses. $^{**}$ \(p<0.05\), $^{***}$ \(p<0.01\).} "
	noisily display " \end{tablenotes} "
	noisily display " \end{threeparttable} "
	noisily display " \end{center} "
	noisily display " \end{landscape} "
	noisily display " \end{singlespace} "
	  
	  log close

	}



  
** Supplementary Tables 

** Table A1: Descriptive Statistics 
	



		estpost summarize idp_origins_loc  el_bri     HSeg2  MSeg2  elf_reg  cfdi_block_eh  density62_new area99   rain_av eh rgl_pc altitude ruggedness av_dist_nr2  
		
		esttab using tablea1.tex, replace f cells("mean(fmt(2)) sd(fmt(2)) count(fmt(0))") noobs label booktabs    nonumber b(a2) alignment(c c c) collabels("\multicolumn{1}{c}{Mean}"  "\multicolumn{1}{c}{SD}"  "\multicolumn{1}{c}{N}" ) 
		eststo clear
	
** Table A2: Controlling for Distance to Specific Native Reserves 



	 

		label variable idp_origins_loc_ln_z "IDP"
		label variable el_bri_ln_z "Fire"
	 
		qui reg idp_origins_loc_ln_z HSeg2_z  `controls'  int_kikuyu_ln_z int_kisii_ln_z   int_luhya_ln_z     if cfdi_block_eh_z~=.  
		est store a

		qui reg idp_origins_loc_ln_z    `controls'   int_kikuyu_ln_z int_kisii_ln_z   int_luhya_ln_z     cfdi_block_eh_z  
		est store b
		
		 
		qui ivregress 2sls  idp_origins_loc_ln_z `controls'  int_kikuyu_ln_z int_kisii_ln_z   int_luhya_ln_z   (   HSeg2_z    = cfdi_block_eh_z    )      , first

		est store c
		estat firststage
		
		mat fstat = r(singleresults)
		estadd scalar fs = fstat[1,4] 

		** Fires 

		** # 2 ELF & SEG  

		qui reg el_bri_ln_z HSeg2_z  `controls'   int_kikuyu_ln_z int_kisii_ln_z   int_luhya_ln_z    if cfdi_block_eh_z~=.  
		est store d
		
		qui reg el_bri_ln_z    `controls'    int_kikuyu_ln_z int_kisii_ln_z   int_luhya_ln_z    cfdi_block_eh_z  
		est store e
		  
		qui ivregress 2sls  el_bri_ln_z `controls'  int_kikuyu_ln_z int_kisii_ln_z   int_luhya_ln_z   (   HSeg2_z    = cfdi_block_eh_z    )      , first
		est store f
		
		
		estat firststage


		mat fstat = r(singleresults)
		estadd scalar fs = fstat[1,4] 


	 

		
		esttab a b c d e f   using tablea2.tex, replace f   label booktabs alignment(c c c c c c) b(2) p(2)      depvars mtitle("\specialcell{{IDP} \\ \emph{OLS}}" "\specialcell{{IDP} \\ \emph{RF}}" "\specialcell{{IDP} \\ \emph{IV}}"  "\specialcell{{Fire} \\ \emph{OLS}}"  "\specialcell{{Fire} \\ \emph{RF}}"  "\specialcell{{Fire} \\ \emph{IV}}") stats(N r2 fs, fmt(0 2) layout("\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}")  labels(`"N"' `"\(R^{2}\)"' `"F-stat Inst."'))  
		eststo clear
			

** Table A3: Accounting for Ethnic Diversity II - Controlling for Ethnic Diversity (IV)



	**save N
	   sum HSeg2_z
	   local n_obs = r(N)
	   display `n_obs'

		
	**************Store Estimates****************
		
		

		
		**First column, OLS results IDPs
		reg idp_origins_loc_ln_z HSeg2_z elf_reg_z `controls'   if   cfdi_block_eh_z~=. & av_dist_nr2_ln_z ~= . 
		estimates store a 
		
		foreach var of varlist HSeg2_z elf_reg_z density62_ln_z area99_ln_z rain_ln_z eh rgl_pc_z altitude_ln_z ruggedness_ln_z{
		
		local coef1_`var' = _b[`var']
		local se1_`var' = _se[`var']
		   
		}
		
		*check formatting
			
			display `coef1_HSeg2_z'
			display %12.2f `coef1_HSeg2_z'
	   
	   ** Second Column, RF results IDPs
	   
		reg idp_origins_loc_ln_z     cfdi_block_eh_z av_dist_nr2_ln_z `controls'   
		estimates store b
		
		
		foreach var of varlist     density62_ln_z area99_ln_z rain_ln_z eh rgl_pc_z altitude_ln_z ruggedness_ln_z cfdi_block_eh_z av_dist_nr2_ln_z {
		
		local coef0_`var' = _b[`var']
		local se0_`var' = _se[`var']
		   
		}
		
	 
	   **Third column, IV results IDPs
	   ivregress 2sls  idp_origins_loc_ln_z  `controls' (   HSeg2_z  elf_reg_z = cfdi_block_eh_z  av_dist_nr2_ln_z )      , first
		estimates store c 
	  
		**Pull out Fstat and save locally  
		estat firststage 
		mat fstat=r(singleresults)
		estadd scalar fstat1=fstat[1,4], replace   
		local fstat = `:display %12.2f e(fstat1)'
		display `fstat'


	   foreach var of varlist HSeg2_z elf_reg_z density62_ln_z area99_ln_z rain_ln_z eh rgl_pc_z altitude_ln_z ruggedness_ln_z{
		
		local coef2_`var' =_b[`var']
		local se2_`var'= _se[`var']
		   
		}


			*check formatting
			
			display `coef2_HSeg2_z'
			display %12.2f `coef2_HSeg2_z'
		
		
		**Fourth column, OLS results FIRE BRIGHT
		reg el_bri_ln_z HSeg2_z elf_reg_z `controls'  if     cfdi_block_eh_z~=. & av_dist_nr2_ln_z ~=. 
		 estimates store d
		 
	   foreach var of varlist HSeg2_z elf_reg_z density62_ln_z area99_ln_z rain_ln_z eh rgl_pc_z altitude_ln_z ruggedness_ln_z{
		
		local coef3_`var' =_b[`var']
		local se3_`var'= _se[`var']
		   
		}
		
		** Fifth column, RF results  FIRE BRIGHT 
		
		 
		reg el_bri_ln_z     cfdi_block_eh_z av_dist_nr2_ln_z `controls'   
		estimates store e
		
		
		foreach var of varlist    density62_ln_z area99_ln_z rain_ln_z eh rgl_pc_z altitude_ln_z ruggedness_ln_z cfdi_block_eh_z av_dist_nr2_ln_z {
		
		local coef5_`var' = _b[`var']
		local se5_`var' = _se[`var']
		   
		}
		
		
		
		**Sixth  column, IV results FIRE BRIGHT
		ivregress 2sls  el_bri_ln_z `controls'  (   HSeg2_z  elf_reg_z = cfdi_block_eh_z  av_dist_nr2_ln_z )      , first
		 estimates store f
		

		foreach var of varlist HSeg2_z elf_reg_z density62_ln_z area99_ln_z rain_ln_z eh rgl_pc_z altitude_ln_z ruggedness_ln_z{
		
		local coef4_`var' =_b[`var']
		local se4_`var'= _se[`var']
		   
		}
		
		
		
		**Table 3.2 First stage results on Segregation
		
		reg HSeg2_z `controls' cfdi_block_eh_z  av_dist_nr2_ln_z
		
		foreach var of varlist cfdi_block_eh_z  av_dist_nr2_ln_z {
		 local coefa_`var' =_b[`var']
		local sea_`var'= _se[`var']
		   
		}
		
		
		
		**Table 3.3  First stage results on Ethnic Fractionalization

		reg elf_reg_z `controls' cfdi_block_eh_z  av_dist_nr2_ln_z

		
		foreach var of varlist cfdi_block_eh_z  av_dist_nr2_ln_z {
		local coefb_`var' =_b[`var']
		local seb_`var'= _se[`var']
		   
		}
		
	 
			
	**************Make Table A3********************
	 


			
			
		  quietly {
			capture log close
		  log using tablea3.tex, text replace

		  noisily display "\begin{singlespace}	"
		  noisily display "	\begin{center}	"
		  noisily display "	\begin{threeparttable}[h]\scriptsize	"
		  noisily display "	\caption{Accounting for Ethnic Diversity II - Controlling for Ethnic Diversity (IV)}\label{table:table6}	"
		  noisily display "	{	"
		  noisily display "	\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}	"
		  noisily display "	\begin{tabular}{l*{6}{c}}	"
		  noisily display "	\toprule	"
		  noisily display "	\emph{Second Stage:} &\multicolumn{3}{c}{\emph{Log. No. of IDPs}}&\multicolumn{3}{c}{\emph{Log. Fire Brightness}}\\	"
		  noisily display "	\cmidrule(lr){2-4}\cmidrule(lr){5-7}	"
		  noisily display "	&\multicolumn{1}{c}{[1]}&\multicolumn{1}{c}{[2]}&\multicolumn{1}{c}{[3]}&\multicolumn{1}{c}{[4]}&\multicolumn{1}{c}{[5]}&\multicolumn{1}{c}{[6]}\\	"
		  noisily display "	&\multicolumn{1}{c}{OLS}&\multicolumn{1}{c}{RF}&\multicolumn{1}{c}{IV}&\multicolumn{1}{c}{OLS}&\multicolumn{1}{c}{RF}&\multicolumn{1}{c}{IV}\\	"
		  noisily display "	\midrule	"
		  
		  noisily display "	Segregation (Theil's Index)& " %12.2f `coef1_HSeg2_z' " &   & " %12.2f `coef2_HSeg2_z' " \sym{***}& " %12.2f `coef3_HSeg2_z' "  &   & " %12.2f `coef4_HSeg2_z' " \\	"
		  noisily display "	& (" %12.2f `se1_HSeg2_z' ")&   & (" %12.2f `se2_HSeg2_z' ") & (" %12.2f `se3_HSeg2_z' ") &   & (" %12.2f `se4_HSeg2_z' ") \\	"
		  
		  noisily display " Ethnic Fractionalization & " %12.2f `coef1_elf_reg_z' " \sym{***} &     &     " %12.2f `coef2_elf_reg_z' " \sym{***}&     " %12.2f `coef3_elf_reg_z' " \sym{***} &      &     " %12.2f `coef4_elf_reg_z' " \sym{**} \\"
		  noisily display "		&   (" %12.2f `se1_elf_reg_z' " )   &         &  (" %12.2f `se2_elf_reg_z' " )        &   (" %12.2f `se3_elf_reg_z' " )      &      &   (" %12.2f `se4_elf_reg_z' " )      \\"
		  
		  noisily display "	Log. Population Density (1962)& " %12.2f `coef1_density62_ln_z' " \sym{**} & " %12.2f `coef0_density62_ln_z' "    & " %12.2f `coef2_density62_ln_z' " \sym{**} & " %12.2f `coef3_density62_ln_z' " & " %12.2f `coef5_density62_ln_z' " \sym{**}   & " %12.2f `coef4_density62_ln_z'  "    \\	"
		  noisily display "	& (" %12.2f `se1_density62_ln_z' ") & (" %12.2f `se0_density62_ln_z' ") & (" %12.2f `se2_density62_ln_z' ") & (" %12.2f `se3_density62_ln_z' ")  & (" %12.2f `se5_density62_ln_z' ") & (" %12.2f `se4_density62_ln_z' ") \\	
		  
		 
		  noisily display "	Log. Area & " %12.2f `coef1_area99_ln_z' "\sym{***}& " %12.2f `coef0_area99_ln_z' "\sym{***}&  " %12.2f `coef2_area99_ln_z' " & " %12.2f `coef3_area99_ln_z' "\sym{***} & " %12.2f `coef5_area99_ln_z' "\sym{***}&    " %12.2f `coef4_area99_ln_z' "\\	"
		  noisily display "	& (" %12.2f `se1_area99_ln_z' ") & (" %12.2f `se0_area99_ln_z' ") & (" %12.2f `se2_area99_ln_z' ") &   (" %12.2f `se3_area99_ln_z' ") &  (" %12.2f `se5_area99_ln_z' ") & (" %12.2f `se4_area99_ln_z' ") \\	"
		  
		  noisily display "	Log. Rainfall & " %12.2f `coef1_rain_ln_z' "  & " %12.2f `coef0_rain_ln_z' " & " %12.2f `coef2_rain_ln_z' " & " %12.2f `coef3_rain_ln_z' "\sym{***}  & " %12.2f `coef5_rain_ln_z' " & " %12.2f `coef4_rain_ln_z' "\\	"
		  noisily display "	& (" %12.2f `se1_rain_ln_z' ") & (" %12.2f `se0_rain_ln_z' ") & (" %12.2f `se2_rain_ln_z' ") & (" %12.2f `se3_rain_ln_z' ")  & (" %12.2f `se5_rain_ln_z' ") & (" %12.2f `se4_rain_ln_z' ") \\	"
		  
		  noisily display "	Alienated Area (1934)& " %12.2f `coef1_eh' "\sym{***}& " %12.2f `coef0_eh' " & " %12.2f `coef2_eh' " & " %12.2f `coef3_eh' " \sym{***} & " %12.2f `coef5_eh' " &   " %12.2f `coef4_eh' " \\	"
		  noisily display "	& (" %12.2f `se1_eh' ") & (" %12.2f `se0_eh' ") & (" %12.2f `se2_eh' ") & (" %12.2f `se3_eh' ") & (" %12.2f `se5_eh' ") & (" %12.2f `se4_eh' ") \\	"
		  
		  noisily display "	Prop. Rangeland & " %12.2f `coef1_rgl_pc_z' " \sym{***}  & " %12.2f `coef5_rgl_pc_z' " \sym{***} & " %12.2f `coef2_rgl_pc_z' " & " %12.2f `coef3_rgl_pc_z' "  & " %12.2f `coef5_rgl_pc_z' "   & " %12.2f `coef4_rgl_pc_z' " \\	"
		  noisily display "	& (" %12.2f `se1_rgl_pc_z' ") & (" %12.2f `se0_rgl_pc_z' ") & (" %12.2f `se2_rgl_pc_z' ") & (" %12.2f `se3_rgl_pc_z' ") &  (" %12.2f `se5_rgl_pc_z' ") & (" %12.2f `se4_rgl_pc_z' ") \\	"
		  
		  noisily display "	Log. Altitude & " %12.2f `coef1_altitude_ln_z' "\sym{***}& " %12.2f `coef0_altitude_ln_z' "\sym{***}& " %12.2f `coef2_altitude_ln_z' "\sym{***} & " %12.2f `coef3_altitude_ln_z' " & " %12.2f `coef5_altitude_ln_z' " &" %12.2f `coef4_altitude_ln_z' "\\	"
		  noisily display "	& (" %12.2f `se1_altitude_ln_z' ") & (" %12.2f `se0_altitude_ln_z' ") & (" %12.2f `se2_altitude_ln_z' ") & (" %12.2f `se3_altitude_ln_z' ") & (" %12.2f `se5_altitude_ln_z' ") & (" %12.2f `se4_altitude_ln_z' ") \\	"
		  
		  noisily display "	Log. Terrain Ruggedness & " %12.2f `coef1_ruggedness_ln_z' "  & " %12.2f `coef0_ruggedness_ln_z' " & " %12.2f `coef2_ruggedness_ln_z' " & " %12.2f `coef3_ruggedness_ln_z' "  & " %12.2f `coef5_ruggedness_ln_z' " & " %12.2f `coef4_ruggedness_ln_z' "\\	"
		  noisily display "	& (" %12.2f `se1_ruggedness_ln_z' ")	& (" %12.2f `se0_ruggedness_ln_z' ")  & (" %12.2f `se2_ruggedness_ln_z' ") & (" %12.2f `se3_ruggedness_ln_z' ") 	& (" %12.2f `se5_ruggedness_ln_z' ") & (" %12.2f `se4_ruggedness_ln_z' ") \\	"
		  
			
		  
			  
			noisily display "	CFDI &  & " %12.2f `coef0_cfdi_block_eh_z ' "\sym{***}  & &   &  " %12.2f `coef5_cfdi_block_eh_z ' " &   \\	"
		  noisily display "	&   & (" %12.2f `se0_cfdi_block_eh_z ' ") & &   & (" %12.2f `se5_cfdi_block_eh_z ' ")  &   \\"	
		  
		  
			noisily display "		Log. Average Distance to  Native Reserves  &  & " %12.2f `coef0_av_dist_nr2_ln_z ' "  & &   &  " %12.2f `coef5_av_dist_nr2_ln_z ' " &   \\	"
		  noisily display "	&   & (" %12.2f `se0_av_dist_nr2_ln_z ' ") & &   & (" %12.2f `se5_av_dist_nr2_ln_z ' ")  &   \\"	
		  
		  
		  noisily display " 		\midrule"
		  noisily display "  \textbf{\emph{First-Stage: Segregation }} &\multicolumn{6}{c}{}\\"
		  noisily display "					\midrule"
		  noisily display "					CDFI           &  &     & " %12.2f `coefa_cfdi_block_eh_z' "\sym{***}&   &   &    " %12.2f `coefa_cfdi_block_eh_z' "\sym{***}\\"
		  noisily display "					&        &     &  ("%12.2f `sea_cfdi_block_eh_z' ")       &  &           &   ("%12.2f `sea_cfdi_block_eh_z' ")        \\"
		  noisily display "					Log. Average Distance to  Native Reserves    &  &  &   " %12.2f `coefa_av_dist_nr2_ln_z' "\sym{***}&     &  &    " %12.2f `coefa_av_dist_nr2_ln_z' "\sym{***}\\"
		  noisily display "				&        &     &   (" %12.2f `sea_av_dist_nr2_ln_z' ")         &         &    &   (" %12.2f `sea_av_dist_nr2_ln_z' ")         \\"
		  noisily display "				\midrule"
		  noisily display "				\textbf{\emph{First-Stage: Ethnic Fractionalization } }&\multicolumn{6}{c}{}\\"
		  noisily display "				\midrule"
		  noisily display "					CDFI      &       &     & " %12.2f `coefb_cfdi_block_eh_z' "\sym{**}&  &    &    " %12.2f `coefb_cfdi_block_eh_z' "\sym{**}\\"
		  noisily display "					&         &    &  ("%12.2f `seb_cfdi_block_eh_z' ")       &        &     &   ("%12.2f `seb_cfdi_block_eh_z' ")        \\"
		  noisily display "					Log. Average Distance to  Native Reserves&   &   &    " %12.2f `coefb_av_dist_nr2_ln_z' "\sym{***}&      &  &   " %12.2f `coefb_av_dist_nr2_ln_z' "\sym{***}\\"
		  noisily display "				&         &    &   (" %12.2f `seb_av_dist_nr2_ln_z' ")         &    &         &   (" %12.2f `seb_av_dist_nr2_ln_z' ")         \\"
		  noisily display "					\midrule"
		  noisily display "					N    &      717         &      717         &      717         &      717       &      717   &      717     \\"
		  noisily display "				Cragg-Donald Stat. &            &   &   7.6      &               & &    7.6        \\"
		  noisily display "				Stock-Yogo Critical Value (0.10)& &            &    7.0         &        &    &    7.0     \\"
		  noisily display "				Stock-Yogo Critical Value (0.15)&   &            &    4.6     &           &  &    4.6         \\"
		  noisily display "				\bottomrule"
		  noisily display "			\end{tabular}"
		  noisily display "		}"
		  noisily display "		\begin{tablenotes}[normal,flushleft]"
		  noisily display "			\item{\emph{Note}:  Continuous variables are standardized to have a mean of 0 and a standard deviation of 0.5. Standard errors in parentheses. $^{**}$ \(p<0.05\), $^{***}$ \(p<0.01\). StockYogo (2005) critical values reported  are for Wald tests of nominal size 0.05 and actual size less than 0.10 and 0.15.}"
		  noisily display "		\end{tablenotes}"
		  noisily display "	\end{threeparttable}"
		  noisily display " \end{center}"
		  noisily display " \end{singlespace}"
		  
		  log close

		}





	
** Table A4: Segregation by Group 
 
	 
		  ivregress 2sls  idp_origins_loc_ln_z  `controls'   (diss_2kalenjin_z =cfdi_block_eh_z )  , first
		   est store a
	 
		

		  ivregress 2sls  idp_origins_loc_ln_z  `controls'   (diss_2kikuyu_z =cfdi_block_eh_z )  , first
		   est store b
	 

		  ivregress 2sls  idp_origins_loc_ln_z  `controls'   (diss_2kisii_z =cfdi_block_eh_z )  , first
		   est store c
	 

		  ivregress 2sls  idp_origins_loc_ln_z  `controls'   (diss_2luhya_z =cfdi_block_eh_z )  , first
		   est store d
		   
	 

		  ivregress 2sls  idp_origins_loc_ln_z  `controls'   (diss_2maasai_z =cfdi_block_eh_z )  , first
		   est store e
	 
	 
	 


		 ivregress 2sls   el_bri_ln_z  `controls'   (diss_2kalenjin_z =cfdi_block_eh_z )  , first
		 est store f
		 
	 
		 
		 ivregress 2sls   el_bri_ln_z  `controls'   (diss_2kikuyu_z =cfdi_block_eh_z )  , first
		 est store g
		 
	 
		 
		 ivregress 2sls   el_bri_ln_z  `controls'   (diss_2kisii_z =cfdi_block_eh_z )  , first
		 est store h
		  
		 
		 ivregress 2sls   el_bri_ln_z  `controls'   (diss_2luhya_z =cfdi_block_eh_z )  , first
		 est store i
		  
		 
		 ivregress 2sls   el_bri_ln_z  `controls'   (diss_2maasai_z=cfdi_block_eh_z )  , first
		 est store j
		  
		 
		esttab a b c d e f g h i j using tablea4.tex,  replace f   label booktabs  keep(diss_2kalenjin_z diss_2kikuyu_z diss_2kisii_z diss_2luhya_z diss_2maasai_z)   alignment(c c c c c c c c c c) b(2) p(2)      stats(N   , fmt(0 ) layout("\multicolumn{1}{c}{@}")  labels(`"N"')) 
		eststo clear
		
 
		
** Table A5: Controlling for Settlement Schemes  


	  
	 
		qui reg idp_origins_loc_ln_z HSeg2_z  `controls' ss_dum   if cfdi_block_eh_z~=.  
		est store a

		qui reg idp_origins_loc_ln_z    `controls'  ss_dum   cfdi_block_eh_z  
		est store b
		
		 
		qui ivregress 2sls  idp_origins_loc_ln_z `controls' ss_dum (   HSeg2_z    = cfdi_block_eh_z    )      , first

		est store c
		estat firststage
		
		mat fstat = r(singleresults)
		estadd scalar fs = fstat[1,4] 

		** Fires 

		** # 2 ELF & SEG  

		qui reg el_bri_ln_z HSeg2_z  `controls'  ss_dum  if cfdi_block_eh_z~=.  
		est store d
		
		qui reg el_bri_ln_z    `controls'   ss_dum  cfdi_block_eh_z  
		est store e
		  
		qui ivregress 2sls  el_bri_ln_z `controls' ss_dum (   HSeg2_z    = cfdi_block_eh_z    )      , first
		est store f
		estat firststage


		mat fstat = r(singleresults)
		estadd scalar fs = fstat[1,4] 


	 

		
		esttab a b c d e f   using tablea5.tex, replace f   label booktabs alignment(c c c c c c) b(2) p(2)      depvars mtitle("\specialcell{{IDP} \\ \emph{OLS}}" "\specialcell{{IDP} \\ \emph{RF}}" "\specialcell{{IDP} \\ \emph{IV}}"  "\specialcell{{Fire} \\ \emph{OLS}}"  "\specialcell{{Fire} \\ \emph{RF}}"  "\specialcell{{Fire} \\ \emph{IV}}" )stats(N r2 fs, fmt(0 2) layout("\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}")  labels(`"N"' `"\(R^{2}\)"' `"F-stat Inst."'))  
		eststo clear
		
 
	
** Table A6: Controlling for NDVI 


 


		qui reg idp_origins_loc_ln_z HSeg2_z  `controls' ndvi_z   if cfdi_block_eh_z~=.  
		est store a

		qui reg idp_origins_loc_ln_z    `controls'  ndvi_z   cfdi_block_eh_z  
		est store b
		
		 
		qui ivregress 2sls  idp_origins_loc_ln_z `controls' ndvi_z (   HSeg2_z    = cfdi_block_eh_z    )      , first

		est store c
		estat firststage
		
		mat fstat = r(singleresults)
		estadd scalar fs = fstat[1,4] 

		** Fires 

		** # 2 ELF & SEG  

		qui reg el_bri_ln_z HSeg2_z  `controls'  ndvi_z  if cfdi_block_eh_z~=.  
		est store d
		
		qui reg el_bri_ln_z    `controls'   ndvi_z  cfdi_block_eh_z  
		est store e
		  
		qui ivregress 2sls  el_bri_ln_z `controls' ndvi_z (   HSeg2_z    = cfdi_block_eh_z    )      , first
		est store f
		estat firststage


		mat fstat = r(singleresults)
		estadd scalar fs = fstat[1,4] 


	 

		
		esttab a b c d e f   using tablea6.tex, replace f   label booktabs alignment(c c c c c c) b(2) p(2)      depvars mtitle("\specialcell{{IDP} \\ \emph{OLS}}" "\specialcell{{IDP} \\ \emph{RF}}" "\specialcell{{IDP} \\ \emph{IV}}"  "\specialcell{{Fire} \\ \emph{OLS}}"  "\specialcell{{Fire} \\ \emph{RF}}"  "\specialcell{{Fire} \\ \emph{IV}}" )stats(N r2 fs, fmt(0 2) layout("\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}")  labels(`"N"' `"\(R^{2}\)"' `"F-stat Inst."'))  
		eststo clear


	


** Table A7: Rural Locations Only 


 

	label variable idp_origins_loc_ln_z "IDP"
	label variable el_bri_ln_z "Fire"
 
	qui reg idp_origins_loc_ln_z HSeg2_z  `controls'    if cfdi_block_eh_z~=. & urban == 0 
    est store a

	qui reg idp_origins_loc_ln_z    `controls'     cfdi_block_eh_z if urban == 0 
    est store b
	
	 
	qui ivregress 2sls  idp_origins_loc_ln_z `controls'  (   HSeg2_z    = cfdi_block_eh_z    )   if urban == 0    , first

    est store c
    estat firststage
    
    mat fstat = r(singleresults)
    estadd scalar fs = fstat[1,4] 

	** Fires 

	** # 2 ELF & SEG  

	qui reg el_bri_ln_z HSeg2_z  `controls'    if cfdi_block_eh_z~=. & urban == 0 
	est store d
	
	qui reg el_bri_ln_z    `controls'     cfdi_block_eh_z if  urban == 0 
	est store e
	  
	qui ivregress 2sls  el_bri_ln_z `controls'  (   HSeg2_z    = cfdi_block_eh_z    )  if urban == 0     , first
    est store f
    estat firststage


    mat fstat = r(singleresults)
    estadd scalar fs = fstat[1,4] 


 
	esttab a b c d e f   using tablea7.tex, replace f   label booktabs alignment(c c c c c c) b(2) p(2)      depvars mtitle("\specialcell{{IDP} \\ \emph{OLS}}" "\specialcell{{IDP} \\ \emph{RF}}" "\specialcell{{IDP} \\ \emph{IV}}"  "\specialcell{{Fire} \\ \emph{OLS}}"  "\specialcell{{Fire} \\ \emph{RF}}"  "\specialcell{{Fire} \\ \emph{IV}}" )stats(N r2 fs, fmt(0 2) layout("\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}")  labels(`"N"' `"\(R^{2}\)"' `"F-stat Inst."'))  
	eststo clear


	
	



	  


